@@ -324,7 +324,7 @@ def tendencia(df,cualma,ma1,ma2,ma3):
         senial="ALCISTA"
 
     elif mavalor1 > mavalor2 and mavalor1 < mavalor3:
-        senial="TENDECIA ALCISTA INICIA"
+        senial="TENDENCIA ALCISTA INICIA"
 
     elif mavalor1 < mavalor2 and mavalor1 < mavalor3:
         senial="BAJISTA"
